<?php

namespace ZondacryptoPay\Paymentpage\Model;

use Magento\Checkout\Model\ConfigProviderInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Payment\Helper\Data;
use ZondacryptoPay\Paymentpage\Model\Ui\Logo;

/**
 * Class ConfigProvider
 *
 * @package ZondacryptoPay\Paymentpage\Model
 */
class ConfigProvider implements ConfigProviderInterface
{
	const PP_CODE = 'zondacryptopay_paymentpage';

	/**
	 * @var PaymentPage
	 */
	private $paymentPageMethod;

    /**
     * @var Logo
     */
    private $logo;

    /**
	 * @throws LocalizedException
	 */
	public function __construct(
        Data $paymentHelper,
        Logo $logo
    ) {
		$this->paymentPageMethod = $paymentHelper->getMethodInstance(self::PP_CODE);
        $this->logo = $logo;
    }

	/**
	 * Retrieve assoc array of checkout configuration
	 *
	 * @return array
	 */
	public function getConfig()
	{
		$config = [];

		if($this->paymentPageMethod->isAvailable()) {
			$config = [
				'payment' => [
					self::PP_CODE => [
						'redirectUrl' => $this->paymentPageMethod->getCheckoutRedirectUrl(),
                        'logoUrl' => $this->logo->getUrl(),
					],
				],
			];
		}

		return $config;
	}
}
